# 1.2
Выяяснилось, что если установить разные расширения использующих одну и ту же обработку, то подмены одного
идентификатора для менеджера не достаточно. Чтобы он поднимал нужную обработку, а не брал первую попавшуюся
нужно иметь 4 уникальных uuid для каждой обработки. Возможно это касается и других типов метаданных,
но пока это очевидно только для обработок и по этому в файле id.json сохраняем все необходимые идентификаторы

## 1.2.6
* fix не корректно устанавливался путь к данным при переиспользовании элементов формы
* fix более дружелюбный вывод ошибок

## 1.2.5
* fix DynamicDirective не распространяется на области того же уровня

## 1.2.4
* new поддержка форм 8.5 (без проверки, просто не падает)

## 1.2.3
* fix сборка через питон при падении не возвращала исключение, что делало невозможным определение падения
автоматических сборок. Перенес обработку исключений в main. Все команды v8unpack теперь возвращают ExtException. 

## 1.2.2
* fix не работала сборка формы из разных областей для расширений

## 1.2.1
* new нормализация путей чтобы обратные слеши виндовс из областей и индексы json работали под linux

# 1.1
Версия 1.0 была сыровата, много осалось старого - файлы 802, 803. Работа с index.json не в полном объеме версии 0.19.
Причесываем чтобы перейти на продуктиве с 0.19 на эту версию.

Одновременное использование в одной конфигурации различных расширений и обработок собранных из
одних исходников привело ещё к одной проблеме - ссылка на объект формы терялась при переиспользовании формы.
Теперь сборщик при разборе не хранит уид родителя, а всегда восстанавливает его при сборке

В index.json теперь не обязательно указывать все перемещаемые файлы. Можно использовать вместо имени
файла "*" - и это будет означать перемещение всех файлов по указанному пути. В обратную сторону так же, 
будут взяты все файлы из указанной папки и добавлены в сборочную директорию.

```json
{
  "Form": {
    "Форма1": {
      "Form.id.json": null,   файл останется на месте
      "Form.obj.bsl": "base/Форма2",
      "*": "base/Форма1" - будут перемещены все файлы кроме 2 -  тех что описаны до *
    }
  }
}
```

# 1.1.6
* fix убрано падение в случаях отсутствия каталога источника, например когда все файлы набираются через индекс.
  
# 1.1.5
* new добавлено возможность делать исключения из * в index.json 
* fix исправлена ошибка неправильной работы index.json под linux

# 1.1.4
* new добавлена возможность указывать * в index.json

# 1.1.3
* fix CommonPicture bin файлы имели неправильное старое имя
 
# 1.1.2
* fix не во всех кейсах отрабатывала замена идентификатора родителя
 
# 1.1.1
* new Восстановление идентификатора родителя формы для внешних обработок, документов, справочников

# 1.0

Пересмотр концепции. Раньше исходил от версии базового объекта 801, 802, 803 - что было ошибочным.
Теперь работа построена от версии конкретного типа или подтипа объекта метаданных. Благодаря этому
код стал чище и убралось множество костылей.  

Класть exe в репозиторий было плохой идеей, репозиторий разбух. Exe убраны, кому надо можно собрать с помощью
build_local.cmd.

* new Убрано кодирование версий форм, изменена структура хранения форм.
* new фича - если в комментарии обработки присутствует строка "ver:", то он заменяется на ver:{product}:{product_version}
* new параметр version больше не имеет значения и не используется. Оставлен для будущего применения для 
сборки 8.1 из 8.2
* new параметр prefix - если указан, то уберет из названия объекта метаданных данный префикс, 
 а при сборке его установит (только для корневых и не заимствованных объектов). Нужно для упрощения сборки 
 различных продуктов из одних и тех же исходников, которые могут одновременно использоваться на одной конфигурации
.
* fix контейнерные типы метаданных не корректно собирались с выключенной опцией auto_include
* fix разборка элементов форм 8.1 
* fix сохранение и восстановление кода из старых файлов с непонятной кодировкой
* fix разбор расширений свежих платформ
* fix поскольку ранее предполагалось что один репозиторий используется для сборки одного продукта
      и папка исходников может содержать файлы для разных версий, то папка назначения при разборке не очищалась.
      Такой подход не прижился - каждый продукт теперь имеет свою папку назначения, которая всегда очищается при
      разборке. Предполагается, что общие части должны быть вынесены в отдельные папке вне папки назначения.

## 1.0.17
* fix в файле include элементов формы убрано слово Form
* 
## 1.0.16
* fix не работало комментирование / раскомментирование директив для внешних обработок старых версий под обычные формы
* fix не работали include элементов формы

## 1.0.15
* fix при отсутствии вложенных индексных файлов, корневой индексный файл не учитывался

## 1.0.14
* fix не устанавливалась версия режима совместимости. 
* fix не разбирались внешние обработки с обычными формами 

## 1.0.13
* fix на свежих платформах при разборке конфигураций появились новые файлы с идексом f и 10 которые терялись,
на всяки случай добавил анализ 8, e.

## 1.0.12
* new поддержка 22 версии "Регистры бухгалтерии" появившихся в ERP 2.5. На первый взгляд это косяк платформы,
а не новая версия (номер версии объекта продублирован в следующем свойстве).

# 0.20
* new Идентификаторы и название объекта метаданных вынесены в отдельный файл *.id.json, Сделано
это для того, чтобы можно было из одних исходников собирать несколько одновременно работающих
в одной конфигурации расширений и обработок (1С испытывает проблемы если в него ставят
несколько расширений где объекты метаданных имеют одинаковые идентификаторы и названия).
* new Изменена структура хранения - раньше простые типы метаданных (всегда 2 файла, типа команд)
хранились плоским списком. Теперь все объекты метаданных хранятся одинаково - папка по имени объекта,
внутри файлы по типам ресурсов.

#0.19
Добавлены динамические директивы. Подробнее в [документации](https://github.com/saby-integration/v8unpack/blob/main/docs/usage.md).

## 0.19.4
* fix не разбирались элементы формы для новых версий платформы 8.3.23+, 19.3 нерабочий билд

## 0.19.3
* new не разбирались элементы формы для новых версий платформы 8.3.23+

## 0.19.2
* fix ресурсы указанные в индекс файле не применялись если в каталоге уже есть этот файл

## 0.19.1
* fix DynamicDirective при разборке не удалялись директивы

# 0.18
* версия 0.17 некорректно работала для обычных форм
  * fix не полностью разобрался с форматом привязок к элементам формы. эта версия исправляет данные проблемы. 
  * fix падало если к элементу привязано ДеревоЗначений (такие связи не разбираются, но теперь 
    и не падают - оставляются как есть)
  * fix элементы обычных форм не корректно разбирались собирались если имена страниц совпадали с именами элементов  
* fix не собиралось если присутствовали обычные и управляемые формы
* new includr элементов формы сама панель не переносится, что позволяет вставлять
  элементы формы на пенель расположенную в любом месте экрана, акутально для обычных форм

## 0.18.5
* fix предыдущие правки повлияли на auto_include элементов управляемых форм, починил
* fix 18.2 сломало комментирование директив в обычных формах

## 0.18.4
* fix auto_include элементов форм не рабтало для файлов перемещенных index.json

## 0.18.3
* fix нашлись какие-то битые привязки в формах 8.2, вроде как выходит что если идет связь с 
несуществующим ид элемента, то это связь с собой.

## 0.18.2
* fix использование управляемых форм в платформе 8.2

## 0.18.1
* fix exe падал если одновременно были оф/уф формы. тип формы (оф/уф) теперь всегда такой
 какой был при разборе, от идеи собирать одну и ту же форму по разному откончательно отказался

# 0.17
* new разбор элементов обычных форм теперь такой же как в управляемых - раньше как оказалось доставался только
 плоский список без элементов на вложенных панелях. Сейчас строится вся иерахия элементов.
* include элементов формы пока не поддерживает элементы где источником данных вляются свойства родителя
* props, params, commands теперь лежат в одном файле с элементами форм, так проще и быстрее, кроме этого это шаг к 
  тому чтобы вместе с элементами форм с include автоматом тянуть все необходимые элементам свойства и команды
* fix includr Для элементов форм работает более корректно
* fix includr не теряет связи команд и свойств, если их нет на форме возникает ошибка

## 0.17.8
* fix при массовой сборке расширений в версию расширения не добавлялось имя продукта

## 0.17.7
* fix 802 падало при сборке форм без элементов - сейчас файл elements создается и для пустых форм
* fix 802 нашлись сложные замусоренные формы. добавил костылей
* fix descent не учитывался при сборке из сабмодулей
 
## 0.17.6
fix имя файла и номер версии добавлялся только в непуской комментарий, сейчас во все заканчивающиеся на ; 

## 0.17.5 
вроде работает

## 0.17.1 - 0.17.4
* устранение ошибок, всплыло куча нюансов со структурой элементови и взаимоствязми со страницами
панелями, реквизитами

# 0.16 - полностью работающих сборок нет
* new элементы форм можно разбивать на файлы, тем самым можно переиспользовать группы элементов на разных формах. 
  Работает аналогично областям кода. Вложенные области элементов не поддерживаются. 
  Подробнее в [документации](https://github.com/saby-integration/v8unpack/blob/main/docs/usage.md).
* new для разбиения областей добавлено новое ключевое слово includr, области помеченные этим словом при разборке
  не обновляют исходники. Нововедение призвано облегчить  редактирование часто переистользуемых областей. 
  includr работает и с элементами формы
* элементы формы снова (как было в 0.12) лежат в одном файле element8XX
* new для ускорения сборки / разборки макеты и html файлы размером более 1Мб не распаковываются
* new информация о версии внешней обработки добавляется в комментарий только если он заканчивается на точку с запятой 

## 0.16.5
* fix при сборке элементов управляемых форм имя элемента с includr менялось на include, аналогичные правки
  для обычных форм 

## 0.16.4
* fix inсludr не работал при сборке элементов форм
* fix descent не работал для файлов с кодом в папках src сабмодулей

## 0.16.3
* fix не работала организация файлов элементов форм в расширениях

## 0.16.2
* fix не разбиралось расширение при отсутствии какого либо типа кода
* fix не собиралось с descent 
* fix более понятные тексты ошибок
* fix unittest не учитывал descent 

## 0.16.1
* fix не сохранялись области элементов форм

# 0.15
* new изменено расширение у файлов содержащих код 1С с "1с" на "bsl", как на общепринятое - используемое
самой 1С. Для расширения bsl на github и gitlab есть подсветка синтаксиса.
* new добавлен параметр processes которым можно ограничить количество используемых утилитой ядер процессора
(по умолчанию использует все).
* new шаблоны табличных документов выгружаются с расширением mxl
* fix убрана отладочная заглушка из-за которой сборка шла в один поток.
* fix некорректно разбиралось Дополнение элемента формы
* fix некорректное поведение при ошибках разбора элементов формы 

для перехода на новую версию тех кто использует index.json, в нём надо заменить .1с на .bsl, а тех кто пользуется\
системой организации кода переименовать все файлы *.1с в *.bsl

## 0.15.5
* fix обычные формы писались с суфиксом 803 - это мешало сборке, теперь 802. В будущем 
  откажусь от нотации 803,802 которая лишь обозначает обычные управляемые формы.  
* fix больше защиты от дурака в указании номера версии числом или строкой
* fix конфигурации 8.2 не разбирались CommonForm, CommonTemplates
* fix DocumentJournal, Subsystem могли терять файл помощи
* fix код модулей в кодировке 1251 в ряде случаев приводил к падению разборки

## 0.15.4
fix падение разборки без параметров

## 0.15.3
fix сборка расширения игнорировала параметр auto_include (всегда было включено)

## 0.15.2
fix непредусмотренный ранее случай при парсинге скобкофайлов и разборе расширений.  

## 0.15.1
fix синтаксическая ошибка падала сборка расширений 
fix ошибка в описании параметра auto_include

# 0.14
* new изменения в формате хранения, некоторые метаднные которые сейчас никак не интерпретируются оставляются
 как есть в виде скобко файлов с расширением c1brace, что дало очень существенный прирост скорости.
* fix для некоторых форм не правильно определялся её тип.

# 0.13 - полностью работающих сборок нет
* поддержка нового формата файлов (с 8.3.16)
* структура хранения элементов формы поменяна для более удобного отслеживания изменений.
* оглавление вложенных объектов формируется на лету, раньше добавить новый объект метаданных 
  можно было только через конфигуратор и если что то менялось надо было ковыряться в уидах,
  теперь модуль собирает всё что есть к моменту сборки в каталоге и сам строит оглавление.  
  Особенно полезно в расширениях. Теперь можно на одной конфе добавить форму, а для остальных конфигураций
  просто пересобрать. Не забудьте почистить репозиторий от лишнего, что давно не используется -
  если раньше вы удалили объект через конфигуратор, а из репозитория нет - теперь он
  опять соберется.  
* файл versions для конфигураций и обработок формируется автоматически 
* поддержаны в каком-то объеме древние конфигурации и формы, для этого отказался от отдельного 
  этапа конвертации в json, теперь это делается по месту. Чуть более полная работа с вариантами форм.
  Плюс это решило ряд проблем с конвертацией Json и определением когда этого делать не надо. Кроме всего
  файловых операций стало существенно меньше.
* descent распространяется на всех файлы в пути которых есть src, это нужно чтобы версионировать файлы в сабмодулях
* элементы формы разбиты на два файла, оглавление и данные - до этого 1С периодически пересортировывала данные и
  было не понятно, правились ли сами элементы.
* общее оглавление (файл versions) формируется автоматически, родные uuid версий теряются.   
* поддержаны всё элементы обычных форм
* конфигурации ут 11 упп 1.3 разбираются, но над сборкой надо ещё поработать

для перехода на новую версию тех кто использует index.json, в нём нужно удалить ссылки на файлы содержащие
 элементы формы или сразу заменить на новые две ссылки.


## 0.13.6
* fix сборка обработок и расширений

## 0.13.5
* new добавлено много типов метаданных, в тестовую конфигурацию 8.3 добавлены все возможные типы
  данных, конфигурация собралась и разоралась
* fix Исправлены недочеты в разборе типов метаданных Bot, CalculationRegister,  
* fix поддерка тип макет Action document = тип 2

## 0.13.4
* fix 0.13.3 была полностью не рабочая. в этой работает старый и проходит вроде новый 

## 0.13.3
* в каком то виде поддержка нового формата файлов (с 8.3.16)
* fix WSReference
* fix в еxe больше нет не нужных модулей
* new поддержка -  тип шаблона формы - графическая схема - без проверки пока

## 0.13.2
* fix потерявшиеся коммиты предыдущих версий, в т.ч. с элементами форм.

## 0.13.1
* fix забыл исправить запускалку
   
## 0.13.0
* fix элемент формы декорации 8.3 покрыто больше вариантов
* fix убраны расхождения при сборке форм документа
* fix ещё один кейс на котором падал разбор скобко файла у УПП 1.3
* fix WSReferenсe корректно разбирается и собирается

# 0.12
* мажорная версия поднята из-за того, что из-за дорабток 0.11.6 можно получить разный код при сборке старыми
  версиями которые не знают о составных index.json из сабмодулей
## 0.12.4 - 11 (стабильная версия)
* для базовой версии расширения можно указать descent=0, тогда файлы будут без числовых суфиксов
* файлы сабмодулей лежащие в src теперь версионируются
* при пакетной сборке к номеру версии расширения добавляется имя продукта, нужно чтобы добавлять в фреш как версии
одного продукта.

## 0.12.3
* новые методы сборки добавлены в инит модуля
## 0.12.2
* new добавлена возможность формировать индексный файл на базе product json - команда IA
## 0.12.1
* fix при проблемах с index.json не всегда выводилось имя файла, теперь когда их может быть несколько это
  стало проблемой
## 0.12.0
* new добавлена возможность массовой сборки / разборки  дистрибутивов - нужно чтобы исключить дублирование
  параметров в системе сборки версий и командных файлах ручной сборки,
  v8unpack добавлены параметры сборки -BA -EA которым в качестве параметра можно передать json файл 
  со списком продуктов и параметры их сборки следующей структуры:
  
      {
        "ERP25PROF2005006": {
            "src": "src/ERP25PROF",
            "bin": "bin/saby_ce_kedo_ERP25PROF_2005006.cfe",
            "temp": "temp", 
            "index": "cmd/ERP25/index.json",
            "version": "80316",
            "descent": 2005006,
            "gui": null,
            "disable": true,
        },
        "БУХ3PROF3000112": {
            "src": "src/БУХ3PROF",
            "bin": "bin/saby_ce_kedo_БУХ3PROF_3000112.cfe",
            "temp": "temp", 
            "index": "cmd/БУХ3/index.json",
            "version": "80314",
            "descent": 3000112
        }	
      }
   
  чтобы избежать дублирования параметров сборки/разборки одного бинарника в cmd файлах можно испльзовать команду
  
      v8unpack.exe -BA cmd/products.json --index ERP25PROF2005006
    
  параметр disable в таком штучном режиме игнорируется    

# 0.11 
* new разобраны элементы основных типов управляемых и обычных форм в отдельные файлы, теперь можно понять какие
элементы формы менялись и мержить одновременные правки
* fix обернуто несколько мест из-за возникало непонятное сообщение при сборке невалидных json после ручных правок 

## 0.11.6
* new добавлена возможность в index.json указать другие (массив) index.json файлы (например из сабмодулей), 
которые будут объеденены с корневым перед началом сборки разборки. Обновление идет по алфавиту, последним 
накладывается основной index.json

## 0.11.5
* fix не убирались комментарии директив при разборе 802 

## 0.11.4
* fix form803 - при захвате формы расширением данных самой формы может не быть
* fix - улучшение читаемости ошибок

## 0.11.3
* fix более читабельные сообщения об ошибках связанных с кривыми записами в index.json

## 0.11.2
* fix добавлено поддержка разбора поля html для 8.2
* fix улучшение читабельности ошибок

## 0.11.1
Как показали отзывы, 1с более разнообразна, много всего при разборе елементов форм было не предусмотрено.

Многое стало более понятным, так и откуда растут ноги у лишних скобок...

* fix много непредусмотренных моментов разбора элементов форм, и не факт что все нашли.
* fix конвертация скобко файлов:
  * xml бинарные файлы начинающиеся с нечитаемых символов падали на этапе конвертации скобкофайлов
  * преобразование многострочного текста для локализованных текстов не всегда работало корректно
  * как оказалось 1с не утруждает себя завершающими скобками не только в конце... поймана с поличным,
  решение одно и оно сложнее - разбирать через схему объекта - которой пока нет.

# 0.10
* new добавлено 30 типов метаданных, конфигурации УПП 1.3 УТ11 разобираются и собираются 
(пока без конфигураций поставщика, если кому то это надо пишите)
* new добавлено 2 типа макета
* new прогрессбары
* new большие файлы содержащие бинарные данные (в основном макеты) больше не конфертируются 
  в json что сократило время сборки разборки с часов до минут. Если ктому то
  надо чтобы бинарные файлы макетов были в чистом виде (а надо это только если
  хотите автоматизировать сборку 1с продукта со сборкой бинарных файлов из исходников
  пишите) 
* fix немного оптимизирована многопоточная работа, кратный прирост скорости
* fix исправлены ошибки разбора некторых типов макетов, изменена структура хранения html
* fix корректная работа с зашифрованными методанными (выгружатся в бинарном виде как есть)
* fix распаковка контейнеров в несколько сотен мегабайт

## 0.10.6
* fix существенное ускорение разбора скобко-файла добавленно в 0.10.3 работало во многих случаях некорректно, 
что приводило к потере данных и битым исходникам 

## 0.10.5
* fix на одной Windows машине наблюдали Permission denied - которые выдавали процессы при попытке одновременно
записать один и тот же файл, или создать один и тот же каталог (возникает когда одна и та же область кода 
используется в нескольких местах), сделать тест повторяющий ситуацию не удалось. Пока просто делаю 3 попытки 
записи с небольшим таймаутом - это решило проблему. Тест который переписывал один и тот же файл параллельно в неколько
процессов на этой и других машинах успешно проходил... итого не понятно, но теперь работает.

## 0.10.4
fix при падении на сборке в code_organizer было не понятно в каком файле ошибка

## 0.10.3
* существенное ускорение разбора скобкофайлов за счет того что вложенный 1с код теперь разбирается
не по символьно а строками целиком. форма с 1Mb вложенного 1С кода раньше разбиралась 2 минуты, теперь 6 сек.

## 0.10.2
* fix модуль и exe-шник версий 0.10.0-1 собирался не полностью

## 0.10.1
* fix номер версии уехал в отдельный файл - не во всех местах было исправлено 
* fix exe собирался не рабочий

# 0.9 
* раньше на стадии конвертации в json пытались декодироваться все файлы без исключения, что приводило к медленному
разбору или зависанию на бинарных файлах. Теперь все что не начинается со скобки считается бинарными файлами. Если в 
макете лежит json файл он так же считается бинарным.

Версия условно не совместима с предыдущими, т.к. в большинстве файлов расширение txt поменялось на bin.
Новое поведение должно существенно повысить скорость сборки / разборки. 
 
Напоминаю, что для макетов Вы можете сами определить расширение файла указав его в комментарии (см.инструкцию)

## 0.9.3
* new добавлен тип метаданных HTTPService
* добавлено сообщение при попытке разобрать зашифрованный модуль, пока зашифрованная часть просто игнорируется.
* fix Общие макеты разбираются корректно
* fix Формы отчетов разбираются и собираются корректно
* fix в 0.9.х все макеты двоичных данных и html не разбирались
* fix пустые макеты двоичных данных собираются более правильно
 
## 0.9.2
* new добавлено 15 типов метаданных
* добавил более понятное сообщение об ошибке на этапе декодирования
* добавлена возможность запускать тесты на неподготовленной машине
* добавлена какая то поддержка сборки конфигураций 8.2
* fix на 0.9.x не работала расборка сборка макетов
* fix во всех предыдущих версиях некорректно разбирались общие макеты

## 0.9.1
* fix разбор скобко файла, данные проблемы есть во всех ранних версиях
  * многострочный текст иногда приводил к ошибке
  * не парсился скобко файл с лишними закрывающими скобками

#0.8
* названия классов метаданных приведены к единственному числу, из-за этого поднята мажорная версия
* добавлена поддержка нового типа метаданных: формы и команды регистра сведений

## 0.8.12
* fix некорректный разбор если в шаблоне лежал json файл. Теперь json помещается в репозиторий как текстовый файл
 (сделать ему расширение json хотелось бы, но тогда придется поменять расширение у скобкофайлов чтобы их различать,
 возможно в будущих версиях)

## 0.8.11
* fix некорректное поведение сборки если расширение конфигурации что то добавляло в главное меню

## 0.8.10
* fix падала разборка если не существовало указанного в параметрах index файла.
* сборка / разборка больше не запускается если указанный index файл не существует или не содержит словарь

## 0.8.9
* правка имя файла и версия продукта добавляются в конец комментария обработки и расширения через точку с запятой
  чтобы получить их за один вызов.
* добавлено вырезание всего начиная с точки с запятой из комментария при разборке.

## 0.8.8
* добавлен параметр gui который позволяет переопределить режим работы интерфейса для расширений. 
Допустимые значения:
  * 0 - Версия 8.2
  * 1 - Версия 8.2. Разрешить Такси
  * 2 - Такси. Разрешить Версия 8.2
  * 3 - Такси
* удален параметр release - сделано в 0.8.2 через файл version.txt

## 0.8.7
* new - в конец комментария обработки и расширения через символ # записывается имя файла и версия,
продукта. Предполагается использовать для проверки версии и организации автообновления. Пока
других способов понять из кода с какой версией продукта имеем дела не придумали.
Если кому то мешает напишите обращением, можно вынести в параметр данное поведение.
* fix - Области include не работали при сборке вложенных объектов
## 0.8.6
* fix - комментарии директив при разборке теперь убираются всегда (fix ставились а не убирались)
## 0.8.5
* Добавлена возможность переопределять через index.json области, для этого в корне файла
  требуется создать служебный элемент "Области include" в содержимом которого указать
  новое имена областям кода - {имя исходной области}:{новое имя области}. Тем самым
  можно организовать выбор реализации в зависимости от типа приложения или конфигурации.
  
    При помощи этой возможности можно реализовать следующий кейс. Например способ получения данных
    отличается в обработке и расширении.  Оборачиваем функцию получения данных в область, 
    а в индексах описываем какую реализацию использовать в том или ином продукте.  
```   
  "Области include": {
      "core_Область1": "core_Область2"
  }
```
* Теперь не обязательно, чтобы область кода была в начале строки 
* fix на тестах можно ограничивать количество потоков
* fix комментарии директив при разборке теперь убираются всегда (раньше только для 801 802), что
было проблемой для обычных форм разрабатываемых на 803

## 0.8.3-4
* при сборке создается папка для бинарника если её нет, раньше падала ошибка

## 0.8.2
* версия расширения теперь выгружается в корень в файл version.txt, системы сборки могут её подменять перед сборкой.

#0.7
* new формы и модули убраны в подпапки, так удобнии дробить код в них, и когда их много
легче ориентироваться.
* fix формы с двоичными данными разбирались не полностью, поменялась 
структура *.form*.json и в т.ч. поэтому поднята мажорная версия
* fix одновременное использование обычных и управляемых форм
* fix макеты с текстовым json объектом корректно разбираются

## 0.7.8
* сборка разборка расширений
  * если указан descent, то за корень берется две папки вверх от папки назначения. Предполагается, что используется
  рекомендованная файловая структура, а она содержит дополнительную папку для каждой конфигурации.
  * номер descent в имени файлов игнорируется при формировании index.json
* более дружественный вывод ошибок экзешником - не выводится весь стек

## 0.7.7
* fix не рабирались некоторые обработки собранные для 802 если они были открыты и пересохранены на платформе 8.3

## 0.7.6
* fix не рабирались обработки собранные для 802 если они были открыты и пересохранены на платформе 8.3

## 0.7.5
* найдено ещё несколько не учтенных вариантов кода в управляемых формах, встритился видимо более старый
формат управляемых форм
* fix код не удалялся из некоторых form803.json

## 0.7.4
* new - встретились новые варианты управляемых форм в которых код лежит в других местах,
добавил более сложную логику доставаяния кода. Так же добавлен вариант когда у обработки 
есть дополнительный файл uuid.1.json
* unittest сборки/разборки показывает расхождение и игнорируюет недостающие закрывающие скобки

## 0.7.3
* fix - в управляемые формы код не собирался, сорри торопился тесты не прогнал
* fix - более читаемые тексты ошибок из подпроцессов
* fix - игнорироване лишних папок (где нет json файла по имени метаданных)

## 0.7.2
* fix - из управляемых форм код не выделялся

## 0.7.1
* fix - одновременное использование обычных и управляемых форм, опечатка
* fix - автоформатирование кода

#0.6
* Добиваем проблему с кодировками в 82, сохраняем первоначальную кодирвку.

## 0.6.19
 * fix решена проблема невалидного хеша расширения
 * fix неправильные параметры запаковки в v8unpack

## 0.6.11+
 * fix ошибок с наследованием расширений друг от друга

## 0.6.10
 * наследование файлов старых версий при работе с расширениями конфигураций
 подробности в [инструкции](https://github.com/saby-integration/v8unpack/blob/main/docs/usage.md)    

## 0.6.9
 * добавлены типы метаданных Определяемые типы и Функциональные области
 * исправлена ошибка, что разбирались только две версии совместимости конфигураций
 * исправлена ошибка разбора без файла индекса из версии 0.6.8

## 0.6.8
  * исходники областей теперь могут лежать в src папке
  * изменение подхода к работе с расширениями
  * наведение порядка в коде автоматом

## 0.6.7
  * fix не убирался BOM из исходников 82
## 0.6.6
  * добавлены объекты План видов характеристик, Параметры сеанса, Расширен объект Справочники
## 0.6.5
  * fix не убирались комментарии директив при разборе кода 82
  * переезд репозитория
## 0.6.4
  * fix в ряде случаев неправильно определялась версия обработки 82
  * fix опечатки  
## 0.6.3
  * правки от fishca
    * тексты ошибок
    * добавлены объекты метаданных - Константы 
## 0.6.2
  * правки от fishca - тексты ошибок, добавлены guid основных метаданных 
## 0.6.1
  * fix Экранирование директив в формах 82

#0.5
* убраны лишние кавычки из кода форм, это мешало собирать под 82 и использовать общий код
* поддержка кода форм с кодировкой win-1251

## 0.5.1
  * Доабвлены объекты метаданных - Перечисления и Элементы стиля
  
#0.4
  * добавлена поддержка версии режима совместимости для расширений
  * изменен формат параметра version, теперь он трех или пятизначный
  * если указана временная папка, то она не удаляется после сборки / разборки

  [подробнее про версии режима совместимости](https://github.com/saby-integration/v8unpack/blob/main/docs/usage.md)  

#0.3
  * исправлены ошибки сборки обработки 82
  * теперь можно заполнить index.json пустыми значениями 
  * изменены параметры командной строки формирования index.json


#0.1
## 0.1.3
  * добавлена проверка, что сборка осуществляется той же версией утилиты

## 0.1.1

  * добавлена сериализация 9 объектов, поддержка разных типов программного кода
  * собирается / разбирается расширение СБИС для 1С БУХ3 

#0.0
* собираются / разбираются:
  * тестовые примеры обработки, расширения, конфигурации
  * внешние обработки СБИС для 8.1, 8.2, 8,3
